C+    create_parameter_range.f
C This file was written by Jonathan A. Sherratt
C Copyright (C) 2011 Heriot-Watt University, Edinburgh, UK
C  
C THIS FILE IS PART OF WAVETRAIN.
C WAVETRAIN SOFTWARE IS INTENDED FOR FREE PERSONAL PRIVATE 
C AND ACADEMIC USE ONLY AND WAS DEVELOPED BY JONATHAN SHERRATT AT 
C HERIOT-WATT UNIVERSITY, EDINBURGH, UK, AND IS PROTECTED BY COPYRIGHT. 
C THE COPYRIGHT OWNER IS HERIOT-WATT UNIVERSITY, WITH THE EXCEPTION OF 
C THE ROUTINES FROM THE PACKAGES AUTO, BLAS, EISPACK, LAPACK AND MINPACK, 
C WHICH ARE INCLUDED WITH PERMISSION, WHICH ARE CLEARLY IDENTIFIED IN 
C THE SOURCE CODE, AND THE USE OF THESE PACKAGES IS UNDER THE CONDITIONS 
C OF THE ORIGINAL OWNERS WHICH ARE AVAILABLE AT 
C http://www.netlib.org/blas/faq.html#2;
C http://www.netlib.org/lapack/#_licensing; 
C http://www.netlib.org/minpack/disclaimer.
C 
C PERSONS OR ORGANISATIONS WISHING TO USE THIS WAVETRAIN SOFTWARE FOR 
C COMMERCIAL PURPOSES OR PURPOSES OTHER THAN ITS ORIGINAL INTENTION 
C SHOULD CONTACT THE OWNERS TO REQUEST SPECIFIC WRITTEN PERMISSIONS.
C 
C DISTRIBUTION: DISTRIBUTION OF WAVETRAIN SOFTWARE, IN PART OR AS 
C A WHOLE, BY ANY MEANS (ELECTRONIC, PRINTED COPY OR OTHERWISE), IS 
C PROHIBITED WITHOUT THE PRIOR WRITTEN PERMISSION OF EITHER HERIOT-WATT 
C UNIVERSITY OR THE AUTHOR JONATHAN A. SHERRATT. ALL REQUESTS FOR SUCH 
C PERMISSION SHOULD BE SENT BY EMAIL TO J.A.SHERRATT@HW.AC.UK; PLEASE 
C INCLUDE THE WORD WAVETRAIN IN THE SUBJECT HEADING OF THE MESSAGE.  
C 
C WARRANTY LIMITATIONS: THE PRODUCT AND SERVICE ARE PROVIDED "AS IS". 
C THE OWNER DISCLAIMS ANY AND ALL WARRANTIES, INCLUDING BUT NOT LIMITED 
C TO, ALL EXPRESSED OR IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
C FOR A PARTICULAR PURPOSE. UNDER NO CIRCUMSTANCES WILL THE OWNER BE 
C LIABLE TO YOU FOR ANY LOSS OF USE, INTERRUPTION OF BUSINESS OR ANY 
C DIRECT, INDIRECT, SPECIAL, INCIDENTAL, AND/OR CONSEQUENTIAL DAMAGES 
C OF ANY KIND (INCLUDING LOSS OF PROFITS) EVEN IF THE OWNER HAS BEEN 
C ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. THE OWNER ACCEPTS NO LEGAL 
C LIABILITY FOR ANY OF THE PRODUCT AND/OR SERVICE SOLD, OFFERED FOR SALE, 
C OR OTHERWISE MADE AVAILABLE FOR PUBLIC OR PRIVATE CONSUMPTION IN 
C RELATION TO THIS SOFTWARE. THE OWNER DOES NOT WARRANT THAT THIS SOFTWARE 
C WILL BE ERROR-FREE.
C  
C+    WHEN A SINGLE PERIODIC TRAVELLING WAVE IS BEING CALCULATED (WITH OR 
C+    WITHOUT STABILITY), NOT AS PART OF A LOOP ACROSS THE PARAMETER 
C+    PLANE, THE FILE temp_files/parameter_range.input IS NEEDED IN ORDER 
C+    TO PROVIDE LIMITS ON THE CONTROL PARAMETER DURING NUMERICAL 
C+    CONTINUATION OF THE PERIODIC TRAVELLING WAVE SOLUTION BRANCH. 
C+    (THESE ARE THE AUTO CONSTANTS RL0 AND RL1). HOWEVER THERE MAY NOT 
C+    BE AN INPUT FILE parameter_range.input. IN THAT CASE, THIS PROGRAM 
C+    CREATES A SUITABLE FILE, CONTAINING NUMBERS THAT ARE A LITTLE 
C+    ABOVE AND BELOW THE DESIRED VALUE OF THE CONTROL PARAMETER, SO THAT
C+    THIS VALUE IS DEFINITELY IN THE INTERIOR OF THE RANGE. ONE
C+    POSSIBILITY WOULD BE TO SET THE RANGE AS
C+    0.9*<CONTROL PARAMETER VALUE> UP TO 
C+    1.1*<CONTROL PARAMETER VALUE> (SAY). HOWEVER, THIS MIGHT NOT BE 
C+    SENSIBLE; FOR INSTANCE THE CONTROL PARAMETER MIGHT BE ZERO, 
C+    OR MIGHT HAVE VERY LARGE VALUES BUT ONLY A SMALL VARIATION. 
C+    SO INSTEAD I BASE THE RANGE OF CONTROL PARAMETER VALUES ON THE 
C+    HOPF BIFURCATION SEARCH RANGE. (THIS IS REALLY THE ONLY AVAILABLE 
C+    RANGE OF CONTROL PARAMETER VALUES). IF THE WAVE SEARCH STRATEGY
C+    AFTER FINDING THE HOPF BIFURCAION POINT IS "DIRECT" THEN THIS IS 
C+    STRAIGHTFORWARD. IF IT IS INDIRECT THEN THERE IS ONLY ONE CONTROL
C+    PARAMETER VALUE ASSOCIATED WITH THE SEARCH RANGE, SO I USE THE
C+    DISTANCE BETWEEN THIS AND THE REQUIRED CONTROL PARAMETER VALUE AS
C+    THE RANGE. HOWEVER THIS WILL FAIL IF THE TWO VALUES HAPPEN TO BE THE
C+    SAME OR VERY CLOSE, SO I USED PPATOL TO PROVIDE A "CUSHION".
C+    NOTE THAT THE RANGE BEING SET IN THIS PROGRAM IS NOT TO DO WITH 
C+    THE CALCULATION OF THE HOPF BIFURCATION POINT -- RATHER IT WILL BE 
C+    USED DURING CONTINUATION OF THE PERIODIC TRAVELLING WAVE SOLUTION 
C+    BRANCH EMANATING FROM THAT POINT. NOTE ALSO THAT THE FILE GENERATED
C+    BY THIS PROGRAM IS ONLY SUITABLE IF IWAVE=0 OR 1. IF IWAVE>1 THEN 
C+    A parameter_range.input MUST BE SUPPLIED BY THE USER TO GIVE A
C+    RANGE IN WHICH TO TRACK THE SOLUTION BRANCH LOOKING FOR FOLDS.
C++     
      IMPLICIT REAL*8 (A-H,K,O-Z)
      LOGICAL AUTO
      OPEN(11,FILE='../temp_files/control_parameters.data'
     &,STATUS='OLD')
      REWIND(11)
      READ(11,*)PP
      READ(11,*)C
      CLOSE(11)
      CALL HBLIMS(PP,C,IHDRCT,PPHOPF,HBLIM1,HBLIM2,AUTO)
      IF (IHDRCT.EQ.0) THEN
      PPRNGE=0.2D0*ABS(HBLIM2-HBLIM1)
C     Note: the decision to use 20% of this parameter range is arbitrary.
      ELSE
      OPEN(16,FILE='../temp_files/defaults.input'
     &,STATUS='OLD')
      REWIND(16)
      READ(16,*)PPATOL
      CLOSE(16)
      IF (IHDRCT.EQ.1) THEN
      PPRNGE=MAX(ABS(PPHOPF-PP),100.0D0*PPATOL)
C     Note: the factor of 100 is arbitrary.
      CRNGE=0.2D0*ABS(HBLIM2-HBLIM1)
C     Note: the decision to use 20% of this parameter range is arbitrary.
      CMIN=C-0.5D0*CRNGE
      CMAX=C+0.5D0*CRNGE
      ELSE
      PPRNGE=MAX(ABS(HBLIM1-PP),100.0D0*PPATOL)
C     Note: This case is the file search method.
C           The factor of 100 is arbitrary.
      ENDIF
      ENDIF
      PPMIN=PP-0.5D0*PPRNGE
      PPMAX=PP+0.5D0*PPRNGE
      OPEN(12,FILE='../temp_files/parameter_range.input'
     &,STATUS='NEW')
      WRITE(12,9000)PPMIN,PPMAX
      IF (IHDRCT.EQ.1) THEN
      WRITE(12,9000)CMIN,CMAX
      ENDIF
      CLOSE(12)
C     Note: when used as an input file for loops across the pp-c parameter
C           plane, the file parameter_range.input in the input_files
C           subdirectory also contains the number of pp and c grid points.
C           However these are not needed here, and the wave speed range
C           is only needed in the case of an "indirect" search strategy.
      STOP
 9000 FORMAT(2E18.10)
      END
