C+    change_expansion_factors.f
C This file was written by Jonathan A. Sherratt
C Copyright (C) 2011 Heriot-Watt University, Edinburgh, UK
C  
C THIS FILE IS PART OF WAVETRAIN.
C WAVETRAIN SOFTWARE IS INTENDED FOR FREE PERSONAL PRIVATE 
C AND ACADEMIC USE ONLY AND WAS DEVELOPED BY JONATHAN SHERRATT AT 
C HERIOT-WATT UNIVERSITY, EDINBURGH, UK, AND IS PROTECTED BY COPYRIGHT. 
C THE COPYRIGHT OWNER IS HERIOT-WATT UNIVERSITY, WITH THE EXCEPTION OF 
C THE ROUTINES FROM THE PACKAGES AUTO, BLAS, EISPACK, LAPACK AND MINPACK, 
C WHICH ARE INCLUDED WITH PERMISSION, WHICH ARE CLEARLY IDENTIFIED IN 
C THE SOURCE CODE, AND THE USE OF THESE PACKAGES IS UNDER THE CONDITIONS 
C OF THE ORIGINAL OWNERS WHICH ARE AVAILABLE AT 
C http://www.netlib.org/blas/faq.html#2;
C http://www.netlib.org/lapack/#_licensing; 
C http://www.netlib.org/minpack/disclaimer.
C 
C PERSONS OR ORGANISATIONS WISHING TO USE THIS WAVETRAIN SOFTWARE FOR 
C COMMERCIAL PURPOSES OR PURPOSES OTHER THAN ITS ORIGINAL INTENTION 
C SHOULD CONTACT THE OWNERS TO REQUEST SPECIFIC WRITTEN PERMISSIONS.
C 
C DISTRIBUTION: DISTRIBUTION OF WAVETRAIN SOFTWARE, IN PART OR AS 
C A WHOLE, BY ANY MEANS (ELECTRONIC, PRINTED COPY OR OTHERWISE), IS 
C PROHIBITED WITHOUT THE PRIOR WRITTEN PERMISSION OF EITHER HERIOT-WATT 
C UNIVERSITY OR THE AUTHOR JONATHAN A. SHERRATT. ALL REQUESTS FOR SUCH 
C PERMISSION SHOULD BE SENT BY EMAIL TO J.A.SHERRATT@HW.AC.UK; PLEASE 
C INCLUDE THE WORD WAVETRAIN IN THE SUBJECT HEADING OF THE MESSAGE.  
C 
C WARRANTY LIMITATIONS: THE PRODUCT AND SERVICE ARE PROVIDED "AS IS". 
C THE OWNER DISCLAIMS ANY AND ALL WARRANTIES, INCLUDING BUT NOT LIMITED 
C TO, ALL EXPRESSED OR IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
C FOR A PARTICULAR PURPOSE. UNDER NO CIRCUMSTANCES WILL THE OWNER BE 
C LIABLE TO YOU FOR ANY LOSS OF USE, INTERRUPTION OF BUSINESS OR ANY 
C DIRECT, INDIRECT, SPECIAL, INCIDENTAL, AND/OR CONSEQUENTIAL DAMAGES 
C OF ANY KIND (INCLUDING LOSS OF PROFITS) EVEN IF THE OWNER HAS BEEN 
C ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. THE OWNER ACCEPTS NO LEGAL 
C LIABILITY FOR ANY OF THE PRODUCT AND/OR SERVICE SOLD, OFFERED FOR SALE, 
C OR OTHERWISE MADE AVAILABLE FOR PUBLIC OR PRIVATE CONSUMPTION IN 
C RELATION TO THIS SOFTWARE. THE OWNER DOES NOT WARRANT THAT THIS SOFTWARE 
C WILL BE ERROR-FREE.
C  
C+    THIS PROGRAM ALTERS THE VARIOUS EXPANSION FACTORS SET IN
C+    THE FILE plot_defaults.input SO THAT THEY CORRESPOND TO
C+    FONTS THAT ARE DEFINED FOR THE x11 TERMINAL TYPE
C+    (IN gnuplot).
C+    THIS PROGRAM MAY BE RUN EITHER AS PART OF THE gnuplot 
C+    SET-UPS, OR AS PART OF THE RUN COMMAND show_text_expansions
C+    (THE INPUT PARAMETER IWHICH INDICATES WHICH OF THESE 
C+    APPLIES).
C++
      IMPLICIT REAL*8 (A-H,K,O-Z)
      PARAMETER (NMAX=999)
      DIMENSION IFONTS(NMAX),EXPAND(NMAX)
      OPEN(11,FILE=
     &'../temp_files/change_expansion_factors.input'
     &,STATUS='OLD')
      REWIND(11)
      READ(11,*)IFONTD
C     IFONTD is the font size specified in plot_defaults.input
      READ(11,*)IWHICH
C     IWHICH=1 corresponds to setting up gnuplot
C     IWHICH=2 corresponds to the run command show_text_expansions
      CLOSE(11)
      OPEN(12,FILE='data_files/fontsizes_sorted.txt'
     &,STATUS='OLD')
      REWIND(12)
C     Now read in available font sizes, eliminating duplicates.
C     Note that duplicates do not cause a problem for gnuplot,
C       which just uses the first suitable font name that it finds.
      NFONT=0
      DO 100 I=1,NMAX
         READ(12,*,END=101)IFTIN
         IF (I.EQ.1) THEN
            NFONT=NFONT+1
            IFONTS(1)=IFTIN
         ELSE
            IF (IFTIN.NE.IFONTS(NFONT)) THEN
               NFONT=NFONT+1
               IFONTS(NFONT)=IFTIN
            ENDIF
         ENDIF
 100  CONTINUE
      IF (IWHICH.EQ.1) THEN
         WRITE(6,9000)NFONT
      ELSE
         WRITE(6,9010)
      ENDIF
 101  CLOSE(12)
C     Now calculate the expansion factors corresponding 
C       to the available font size
      DO 200 I=1,NFONT
         EXPAND(I)=(IFONTS(I)+0.001D0)/(IFONTD)
 200  CONTINUE
      IF (IWHICH.EQ.1) THEN
C        Now replace the expansion factors specified in 
C          plot_defaults.input with whichever of EXPAND(.)
C          is closest in numerical value.
         OPEN(13,FILE=
     &'data_files/textexpand_screen.txt'
     &,STATUS='OLD')
         REWIND(13)
         OPEN(14,FILE=
     &'data_files/textexpand_screen_new.txt'
     &,STATUS='NEW')
         OPEN(15,FILE=
     &'data_files/textexpand_screen.nlines'
     &,STATUS='OLD')
         REWIND(15)
         READ(15,*)NLINES
         CLOSE(15)
         DO 300 ILINE=1,NLINES
            READ(13,*)FACTOR
            SEPMIN=ABS(FACTOR-EXPAND(1))
            IMIN=1
            DO 400 I=2,NFONT
               SEP=ABS(FACTOR-EXPAND(I))
               IF (SEP.LT.SEPMIN) THEN
                  SEPMIN=SEP
                  IMIN=I
               ENDIF
 400        CONTINUE
            WRITE(14,9001)EXPAND(IMIN)
 300     CONTINUE
         CLOSE(13)
         CLOSE(14)
      ELSE
C        For IWHICH=2, just write out the values of EXPAND(.) to the screen
         WRITE(6,9002)
         DO 500 I=1,NFONT
            WRITE(6,9003)EXPAND(I)
 500     CONTINUE
      ENDIF
      STOP
 9000 FORMAT('WARNING: there are an unexpectedly large number',/,
     &'         of available fonts, and Wavetrain has',/,
     &'         truncated the font list. Plotting will',/,
     &'         proceed using only the first ',I3,'fonts')
 9001 FORMAT(F20.8)
 9002 FORMAT('The following is a list of text expansion factors',/,
     &     'at which text sizes will change for screen plots.',/,
     &     'The various expansion factors in plot_defaults.input',/,
     &     'will be changed to the closest one of the factors',/,
     &     'below. Note that this is for screen plots only:',/,
     &     'for postscript plots, text expansion occurs on a',/,
     &     'continuous scale.')
 9003 FORMAT(F14.3)
 9010 FORMAT('WARNING: there are an unexpectedly large number',/,
     &'         of available fonts, and Wavetrain has',/,
     &'         truncated the font list.')
      END
