#+ postscript.gp
# This file was written by Jonathan A. Sherratt
# Copyright (C) 2011 Heriot-Watt University, Edinburgh, UK
#  
# THIS FILE IS PART OF WAVETRAIN.
# WAVETRAIN SOFTWARE IS INTENDED FOR FREE PERSONAL PRIVATE 
# AND ACADEMIC USE ONLY AND WAS DEVELOPED BY JONATHAN SHERRATT AT 
# HERIOT-WATT UNIVERSITY, EDINBURGH, UK, AND IS PROTECTED BY COPYRIGHT. 
# THE COPYRIGHT OWNER IS HERIOT-WATT UNIVERSITY, WITH THE EXCEPTION OF 
# THE ROUTINES FROM THE PACKAGES AUTO, BLAS, EISPACK, LAPACK AND MINPACK, 
# WHICH ARE INCLUDED WITH PERMISSION, WHICH ARE CLEARLY IDENTIFIED IN 
# THE SOURCE CODE, AND THE USE OF THESE PACKAGES IS UNDER THE CONDITIONS 
# OF THE ORIGINAL OWNERS WHICH ARE AVAILABLE AT 
# http://www.netlib.org/blas/faq.html#2;
# http://www.netlib.org/lapack/#_licensing; 
# http://www.netlib.org/minpack/disclaimer.
# 
# PERSONS OR ORGANISATIONS WISHING TO USE THIS WAVETRAIN SOFTWARE FOR 
# COMMERCIAL PURPOSES OR PURPOSES OTHER THAN ITS ORIGINAL INTENTION 
# SHOULD CONTACT THE OWNERS TO REQUEST SPECIFIC WRITTEN PERMISSIONS.
# 
# DISTRIBUTION: DISTRIBUTION OF WAVETRAIN SOFTWARE, IN PART OR AS 
# A WHOLE, BY ANY MEANS (ELECTRONIC, PRINTED COPY OR OTHERWISE), IS 
# PROHIBITED WITHOUT THE PRIOR WRITTEN PERMISSION OF EITHER HERIOT-WATT 
# UNIVERSITY OR THE AUTHOR JONATHAN A. SHERRATT. ALL REQUESTS FOR SUCH 
# PERMISSION SHOULD BE SENT BY EMAIL TO J.A.SHERRATT@HW.AC.UK; PLEASE 
# INCLUDE THE WORD WAVETRAIN IN THE SUBJECT HEADING OF THE MESSAGE.  
# 
# WARRANTY LIMITATIONS: THE PRODUCT AND SERVICE ARE PROVIDED "AS IS". 
# THE OWNER DISCLAIMS ANY AND ALL WARRANTIES, INCLUDING BUT NOT LIMITED 
# TO, ALL EXPRESSED OR IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE. UNDER NO CIRCUMSTANCES WILL THE OWNER BE 
# LIABLE TO YOU FOR ANY LOSS OF USE, INTERRUPTION OF BUSINESS OR ANY 
# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, AND/OR CONSEQUENTIAL DAMAGES 
# OF ANY KIND (INCLUDING LOSS OF PROFITS) EVEN IF THE OWNER HAS BEEN 
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. THE OWNER ACCEPTS NO LEGAL 
# LIABILITY FOR ANY OF THE PRODUCT AND/OR SERVICE SOLD, OFFERED FOR SALE, 
# OR OTHERWISE MADE AVAILABLE FOR PUBLIC OR PRIVATE CONSUMPTION IN 
# RELATION TO THIS SOFTWARE. THE OWNER DOES NOT WARRANT THAT THIS SOFTWARE 
# WILL BE ERROR-FREE.
#  
#+ THIS FILE CONTAINS A gnuplot MACRO FOR SETTING 
#+ SUBSEQUENT COMMANDS TO WRITE TO AN ENCAPSULATED POSTSCRIPT 
#+ FILE, WHOSE NAME (WITHOUT EXTENSION) IS THE FIRST ARGUMENT.
#+ THERE MAY (OR MAY NOT) ALSO BE A SECOND ARGUMENT, WHICH IS
#+ THE ASPECT RATIO OF THE POSTSCRIPT PLOT.
#++
if ("$#"==0) print "ERROR: no filename was given" ; exit
if ("$#">2) print "ERROR: too many arguments. A filename (without extension)" ; \
            print "       is required, and optionally the aspect ratio of" ; \
	    print "       the postscript plot can also be given." ; exit
if ("$#"==1) aspectratio=1.0 ; else aspectratio="$1"
unset multiplot ; mpon="no"
set terminal @default_terminal
set output
canvaswidthchars=screenwidthchars
clear
system "fixboundingbox.script ".gprintf("%9.6f",bottomspace)." ".gprintf("%9.6f",leftspace)." ".gprintf("%9.6f",rightspace)." ".gprintf("%9.6f",topspace)." 1"
# This initial return to screen output is included in case a 
#   postscript file is currently being written; this line 
#   completes the writing of this file. This must be done 
#   before plotprepare_ps.script is run in order that
#   confirmation is requested if the postscript
#   file name that is entered is the same as the one
#   that was being written.
system "../plotprepare_ps.script ".subdir." $0".gprintf("%7.4f",aspectratio)." $#"
if (system("cat ../temp_files/plotprepare.error") eq "1") exit
if (system("cat ../temp_files/plotprepare.error") eq "2") exit
# Note that if plotprepare.error contains 2, then endrecord.script has already been run
# Now calculate plot size
if (aspectratio>0.66) xsize=6*1.0 ; ysize=xsize/aspectratio ; canvaswidthchars=137 ; \
   else ysize=9*1.0 ; xsize=ysize*aspectratio ; canvaswidthchars=int((137*xsize)/6.0)
# Note that the value of 137 is for Helvetica,14 font (this is based on trial and error)
# Now do terminal setting for postscript file
pscmd="set terminal postscript eps color size ".gprintf("%9.5f",xsize)."in,".gprintf("%9.5f",ysize)."in enhanced ".psfontname
@pscmd
set output "../../postscript_files/".subdir."/$0.eps"
call "data_files/textexpand_ps.gp"
call "data_files/textfactors_ps.gp"
call "data_files/textmisc_ps.gp"
