#+ pplane.gp
# This file was written by Jonathan A. Sherratt
# Copyright (C) 2011 Heriot-Watt University, Edinburgh, UK
#  
# THIS FILE IS PART OF WAVETRAIN.
# WAVETRAIN SOFTWARE IS INTENDED FOR FREE PERSONAL PRIVATE 
# AND ACADEMIC USE ONLY AND WAS DEVELOPED BY JONATHAN SHERRATT AT 
# HERIOT-WATT UNIVERSITY, EDINBURGH, UK, AND IS PROTECTED BY COPYRIGHT. 
# THE COPYRIGHT OWNER IS HERIOT-WATT UNIVERSITY, WITH THE EXCEPTION OF 
# THE ROUTINES FROM THE PACKAGES AUTO, BLAS, EISPACK, LAPACK AND MINPACK, 
# WHICH ARE INCLUDED WITH PERMISSION, WHICH ARE CLEARLY IDENTIFIED IN 
# THE SOURCE CODE, AND THE USE OF THESE PACKAGES IS UNDER THE CONDITIONS 
# OF THE ORIGINAL OWNERS WHICH ARE AVAILABLE AT 
# http://www.netlib.org/blas/faq.html#2;
# http://www.netlib.org/lapack/#_licensing; 
# http://www.netlib.org/minpack/disclaimer.
# 
# PERSONS OR ORGANISATIONS WISHING TO USE THIS WAVETRAIN SOFTWARE FOR 
# COMMERCIAL PURPOSES OR PURPOSES OTHER THAN ITS ORIGINAL INTENTION 
# SHOULD CONTACT THE OWNERS TO REQUEST SPECIFIC WRITTEN PERMISSIONS.
# 
# DISTRIBUTION: DISTRIBUTION OF WAVETRAIN SOFTWARE, IN PART OR AS 
# A WHOLE, BY ANY MEANS (ELECTRONIC, PRINTED COPY OR OTHERWISE), IS 
# PROHIBITED WITHOUT THE PRIOR WRITTEN PERMISSION OF EITHER HERIOT-WATT 
# UNIVERSITY OR THE AUTHOR JONATHAN A. SHERRATT. ALL REQUESTS FOR SUCH 
# PERMISSION SHOULD BE SENT BY EMAIL TO J.A.SHERRATT@HW.AC.UK; PLEASE 
# INCLUDE THE WORD WAVETRAIN IN THE SUBJECT HEADING OF THE MESSAGE.  
# 
# WARRANTY LIMITATIONS: THE PRODUCT AND SERVICE ARE PROVIDED "AS IS". 
# THE OWNER DISCLAIMS ANY AND ALL WARRANTIES, INCLUDING BUT NOT LIMITED 
# TO, ALL EXPRESSED OR IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE. UNDER NO CIRCUMSTANCES WILL THE OWNER BE 
# LIABLE TO YOU FOR ANY LOSS OF USE, INTERRUPTION OF BUSINESS OR ANY 
# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, AND/OR CONSEQUENTIAL DAMAGES 
# OF ANY KIND (INCLUDING LOSS OF PROFITS) EVEN IF THE OWNER HAS BEEN 
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. THE OWNER ACCEPTS NO LEGAL 
# LIABILITY FOR ANY OF THE PRODUCT AND/OR SERVICE SOLD, OFFERED FOR SALE, 
# OR OTHERWISE MADE AVAILABLE FOR PUBLIC OR PRIVATE CONSUMPTION IN 
# RELATION TO THIS SOFTWARE. THE OWNER DOES NOT WARRANT THAT THIS SOFTWARE 
# WILL BE ERROR-FREE.
#  
#+ THIS gnuplot COMMAND FILE PLOTS A PARAMETER PLANE SHOWING
#+ WHETHER THERE IS A PERIODIC TRAVELLING WAVE, AND (IF THIS WAS
#+ CALCULATED) WHETHER OR NOT IT IS STABLE. THE DIFFERENT OUTCOMES ARE
#+ INDICATED BY DIFFERENT COLOURS; THESE ARE SET IN THE PLOTTING STYLE
#+ FILE AND CAN BE SEEN IN ../../postscript_files/pplane_key.ps, WHICH
#+ IS GENERATED AS PART OF THE STARTUP PROCESS OF PLOTTING. IT CAN BE
#+ REDONE BY TYPING pplane_key. OUTPUT EITHER CONSISTS OF COLOURED
#+ VALUES OF THE WAVE PERIOD, COLOURED DOTS OR COLOURED RCODE NUMBERS:
#+ (THE RCODE NUMBERS ARE USEFUL FOR SUBSEQUENT PLOTTING OF THE
#+ CORRESPONDING SPECTRA.)
#++
if ("$#">0) print "ERROR: no arguments are expected" ; exit
unset label
unset xlabel
unset ylabel
unset multiplot ; mpon="no"
unset xzeroaxis
unset yzeroaxis
set tics nooffset
system "../plotprepare_pplane.script ".subdir." ".pcode." ".pplanetype." ".pplanekeytype." ".gprintf("%18.10g",pplanegap)
if (system("cat ../temp_files/plotprepare.error") eq "1") exit
title1=titlesexpand.system("getline.script 1 ../temp_files/plotprepare_pplane.output").textend
if (system("cat ../temp_files/getline.error") eq "1") exit
title2=titlesexpand.system("getline.script 2 ../temp_files/plotprepare_pplane.output").textend
if (system("cat ../temp_files/getline.error") eq "1") exit
xlabeltext=labelsexpand.system("getline.script 3 ../temp_files/plotprepare_pplane.output").textend
if (system("cat ../temp_files/getline.error") eq "1") exit
ylabeltext=labelsexpand.system("getline.script 4 ../temp_files/plotprepare_pplane.output").textend
if (system("cat ../temp_files/getline.error") eq "1") exit
thispplanetype=system("getline.script 5 ../temp_files/plotprepare_pplane.output")
if (system("cat ../temp_files/getline.error") eq "1") exit
set size 1.0-leftspace-rightspace,1.0-topspace-bottomspace
set origin leftspace,bottomspace
set xlabel xlabeltext textcolor rgb "black"
set ylabel ylabeltext textcolor rgb "black"
xmin=system("getline.script 1 data_files/pplane_axes_limits.data")
if (system("cat ../temp_files/getline.error") eq "1") exit
xmax=system("getline.script 2 data_files/pplane_axes_limits.data")
if (system("cat ../temp_files/getline.error") eq "1") exit
ymin=system("getline.script 3 data_files/pplane_axes_limits.data")
if (system("cat ../temp_files/getline.error") eq "1") exit
ymax=system("getline.script 4 data_files/pplane_axes_limits.data")
if (system("cat ../temp_files/getline.error") eq "1") exit
set xrange [xmin:xmax] noreverse writeback 
set yrange [ymin:ymax] noreverse writeback
if (showtitles eq "yes") set label title1 at screen xtitle,(1.0-topspace*0.25) center textcolor rgb "black" \
 offset character 0,(titlesfactor-1.0)*0.5
if (showtitles eq "yes") set label title2 at screen xtitle,(1.0-topspace*0.75) center textcolor rgb "black" \
 offset character 0,(titlesfactor-1.0)*0.5
empty0=system("emptytest.script data_files/blankpplane.data")
if (system("cat ../temp_files/emptytest.error") eq "1") exit
if (empty0==1) thispplanetype="none"
if (empty0==1) load "pplane_blank.gp"
if (thispplanetype eq "symbol") load "pplane_symbol.gp"
if (thispplanetype eq "rcode") load "pplane_rcode.gp"
if (thispplanetype eq "period") load "pplane_period.gp"
# Note: don't unset xlabel, ylabel or label: leave as
#       they are so that loci etc can be added via replot
# Note also: there is no need to use restore on 
#       xrange and yrange since these are set explicitly.
ifl=0 # This initialises the counter
ihb=0 # This initialises the counter
ipc=0 # This initialises the counter
isb=0 # This initialises the counter
ish=0 # This initialises the counter
iline=0 # This initialises the counter
ilpf=0 # This initialises the counter
