#+ shade.gp
# This file was written by Jonathan A. Sherratt
# Copyright (C) 2011 Heriot-Watt University, Edinburgh, UK
#  
# THIS FILE IS PART OF WAVETRAIN.
# WAVETRAIN SOFTWARE IS INTENDED FOR FREE PERSONAL PRIVATE 
# AND ACADEMIC USE ONLY AND WAS DEVELOPED BY JONATHAN SHERRATT AT 
# HERIOT-WATT UNIVERSITY, EDINBURGH, UK, AND IS PROTECTED BY COPYRIGHT. 
# THE COPYRIGHT OWNER IS HERIOT-WATT UNIVERSITY, WITH THE EXCEPTION OF 
# THE ROUTINES FROM THE PACKAGES AUTO, BLAS, EISPACK, LAPACK AND MINPACK, 
# WHICH ARE INCLUDED WITH PERMISSION, WHICH ARE CLEARLY IDENTIFIED IN 
# THE SOURCE CODE, AND THE USE OF THESE PACKAGES IS UNDER THE CONDITIONS 
# OF THE ORIGINAL OWNERS WHICH ARE AVAILABLE AT 
# http://www.netlib.org/blas/faq.html#2;
# http://www.netlib.org/lapack/#_licensing; 
# http://www.netlib.org/minpack/disclaimer.
# 
# PERSONS OR ORGANISATIONS WISHING TO USE THIS WAVETRAIN SOFTWARE FOR 
# COMMERCIAL PURPOSES OR PURPOSES OTHER THAN ITS ORIGINAL INTENTION 
# SHOULD CONTACT THE OWNERS TO REQUEST SPECIFIC WRITTEN PERMISSIONS.
# 
# DISTRIBUTION: DISTRIBUTION OF WAVETRAIN SOFTWARE, IN PART OR AS 
# A WHOLE, BY ANY MEANS (ELECTRONIC, PRINTED COPY OR OTHERWISE), IS 
# PROHIBITED WITHOUT THE PRIOR WRITTEN PERMISSION OF EITHER HERIOT-WATT 
# UNIVERSITY OR THE AUTHOR JONATHAN A. SHERRATT. ALL REQUESTS FOR SUCH 
# PERMISSION SHOULD BE SENT BY EMAIL TO J.A.SHERRATT@HW.AC.UK; PLEASE 
# INCLUDE THE WORD WAVETRAIN IN THE SUBJECT HEADING OF THE MESSAGE.  
# 
# WARRANTY LIMITATIONS: THE PRODUCT AND SERVICE ARE PROVIDED "AS IS". 
# THE OWNER DISCLAIMS ANY AND ALL WARRANTIES, INCLUDING BUT NOT LIMITED 
# TO, ALL EXPRESSED OR IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE. UNDER NO CIRCUMSTANCES WILL THE OWNER BE 
# LIABLE TO YOU FOR ANY LOSS OF USE, INTERRUPTION OF BUSINESS OR ANY 
# DIRECT, INDIRECT, SPECIAL, INCIDENTAL, AND/OR CONSEQUENTIAL DAMAGES 
# OF ANY KIND (INCLUDING LOSS OF PROFITS) EVEN IF THE OWNER HAS BEEN 
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. THE OWNER ACCEPTS NO LEGAL 
# LIABILITY FOR ANY OF THE PRODUCT AND/OR SERVICE SOLD, OFFERED FOR SALE, 
# OR OTHERWISE MADE AVAILABLE FOR PUBLIC OR PRIVATE CONSUMPTION IN 
# RELATION TO THIS SOFTWARE. THE OWNER DOES NOT WARRANT THAT THIS SOFTWARE 
# WILL BE ERROR-FREE.
#  
#+ THIS gnuplot COMMAND FILE SHADES A REGION
#+ OF THE CONTROL PARAMETER -- WAVE SPEED PLANE.
#+ THERE ARE EITHER THREE OR FOUR ARGUMENTS:
#+       ARG 1: COLOUR TO USE FOR SHADING
#+              (MUST BE A WAVETRAIN COLOUR)
#+       ARG 2: PATTERN TO USE FOR SHADING
#+              (A SINGLE DIGIT BETWEEN 1 AND 7)
#+       ARG 3: MUST BE IN QUOTATIONS ("..."): THE BOUNDING
#+              CURVES, WITH EACH SPECIFIED BY A TWO LETTER
#+              CURVE TYPE (hl/pc/fl/sb), THEN A THREE DIGIT
#+              CODE NUMBER (the corresponding curve number)
#+              AND FINALLY ONE OR MORE INEQUALITIES SPECIFYING
#+              THE PART OF THE CURVE TO BE USED. THUS SOME 
#+              EXAMPLES OF CURVE SPECIFIERS WOULD BE:
#+                 hl 103 R>4&R<=2&c>1.3
#+                 sb 112 delta>=5&delta<=7
#+                 pc 109 c<5.2&A<2.4
#+                 fl 101 all
#+              (THE LAST OF THESE PLOTS THE WHOLE OF THE FOLD LOCUS 
#+              WITH CODE NUMBER 101).
#+              NOTE THAT THE SERIES OF BOUNDING CURVE SPECIFICATIONS
#+              MUST BE ENCLOSED IN QUOTATIONS.
#+       ARG 4: [OPTIONAL: IF PRESENT, MUST BE IN QUOTATIONS ("...")].
#+              TEXT FOR THE KEY. MULTIPLE TEXT LINES ARE PERMITTED,
#+              WITH LINE BREAKS INDICATED BY A DOUBLE BACKSLASH (\\).
#++
if ("$#"<3) print "ERROR: not enough arguments" ; exit
if ("$#">4) print "ERROR: too many arguments" ; exit
ish=ish+1
if ("$#" == 3) system '../plotprepare_shade.script '.pdir.' $0 $1 "$2"'
if (system("cat ../temp_files/plotprepare.error") eq "1") exit
if ("$#" == 4) system '../plotprepare_shade.script '.pdir.' $0 $1 "$2" "$3"'
if (system("cat ../temp_files/plotprepare.error") eq "1") exit
system "copyfile.script data_files/shade.data data_files/shade.gpdata_".ish
if (system("cat ../temp_files/copyfile.error") eq "1") exit
call "reset_output.gp"
shadecolourhex=system("translate_colour.script wtc$0")
shadecolour='rgb "'.shadecolourhex.'"'
if (system("cat ../temp_files/translate_colour.error") eq "1") exit
shadecmd='"data_files/shade.gpdata_'.ish.'" using 1:2 with filledcurves linecolor '.shadecolour." fillstyle pattern $1 noborder"
replot @shadecmd
# END OF GNUPLOT COMMAND FILE
